==> dolphin-16.04.2.tar.xz: dolphin-16.04.2/src/settings/kcm/kcmdolphinviewmodes.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Peter Penz <peter.penz19@gmail.com>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#ifndef KCMDOLPHINVIEWMODES_H
#define KCMDOLPHINVIEWMODES_H

#include <kcmodule.h>

class ViewSettingsTab;

/**
 * @brief Allow to configure the Dolphin views.
 */
class DolphinViewModesConfigModule : public KCModule
{
    Q_OBJECT

public:
    DolphinViewModesConfigModule(QWidget* parent, const QVariantList& args);
    virtual ~DolphinViewModesConfigModule();

    virtual void save() Q_DECL_OVERRIDE;
    virtual void defaults() Q_DECL_OVERRIDE;

private:
    void reparseConfiguration();

private Q_SLOTS:
   void viewModeChanged();

private:
    QList<ViewSettingsTab*> m_tabs;
};

#endif

==> dolphin_18.04.0.orig.tar.xz: dolphin-18.04.0/src/settings/kcm/kcmdolphinviewmodes.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Peter Penz <peter.penz19@gmail.com>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#ifndef KCMDOLPHINVIEWMODES_H
#define KCMDOLPHINVIEWMODES_H

#include <kcmodule.h>

class ViewSettingsTab;

/**
 * @brief Allow to configure the Dolphin views.
 */
class DolphinViewModesConfigModule : public KCModule
{
    Q_OBJECT

public:
    DolphinViewModesConfigModule(QWidget* parent, const QVariantList& args);
    ~DolphinViewModesConfigModule() override;

    void save() override;
    void defaults() override;

private:
    void reparseConfiguration();

private Q_SLOTS:
   void viewModeChanged();

private:
    QList<ViewSettingsTab*> m_tabs;
};

#endif
